# Visualization Module

The `wandas.visualization` module provides functionality for visually representing audio data.

## Plotting

Provides plotting functions for visualizing audio data.

::: wandas.visualization.plotting
